@@ -1,45 +1,40 @@
 # Leaflet plugin version
-leafletprovidersESP_v <- "v1.3.3"
+leaf_providers_esp_v <- "v1.3.3"
 
-
-#' Include base tiles of Spanish public administrations on a \CRANpkg{leaflet}
+#' Add a tile layer from Spanish public administrations to a \CRANpkg{leaflet}
 #' map
 #'
-#' @description
-#' Include tiles of public Spanish organisms to a [leaflet::leaflet()] map.
+#' @encoding UTF-8
+#' @inheritParams leaflet::addProviderTiles
+#' @inherit leaflet::addProviderTiles return
+#' @family images
+#' @export
 #'
-#' @family imagery utilities
-#' @seealso [leaflet::leaflet()], [leaflet::addTiles()]
-#'
-#' @rdname addProviderEspTiles
-#' @name addProviderEspTiles
+#' @seealso
+#' [leaflet::leaflet()], [leaflet::addTiles()], [leaflet::addWMSTiles()],
+#' [esp_tiles_providers].
 #'
 #' @source
 #' <https://dieghernan.github.io/leaflet-providersESP/> leaflet plugin,
-#'  **`r leafletprovidersESP_v`**.
+#'  **`r leaf_providers_esp_v`**.
 #'
-#' @return A modified [leaflet::leaflet()] `map` object.
+#' @param provider the name of the provider, see [esp_tiles_providers] or
+#'   <https://dieghernan.github.io/leaflet-providersESP/preview/>.
 #'
-#' @export
-#'
-#' @param provider Name of the provider, see [esp_tiles_providers] for
-#'   values available.
-#' @inheritParams leaflet::addProviderTiles
-#' @inheritParams leaflet::addTiles
 #'
 #' @examples
 #' library(leaflet)
-#' leafmap <- leaflet(width = "100%", height = "60vh") %>%
-#'   setView(lat = 40.4166, lng = -3.7038400, zoom = 10) %>%
-#'   addTiles(group = "Default (OSM)") %>%
+#' leafmap <- leaflet(width = "100%", height = "60vh") |>
+#'   setView(lat = 40.4166, lng = -3.7038400, zoom = 10) |>
+#'   addTiles(group = "Default (OSM)") |>
 #'   addProviderEspTiles(
 #'     provider = "IDErioja.Claro",
 #'     group = "IDErioja Claro"
-#'   ) %>%
+#'   ) |>
 #'   addProviderEspTiles(
 #'     provider = "RedTransporte.Carreteras",
 #'     group = "Carreteras"
-#'   ) %>%
+#'   ) |>
 #'   addLayersControl(
 #'     baseGroups = c("IDErioja Claro", "Default (OSM)"),
 #'     overlayGroups = "Carreteras",
@@ -47,32 +42,29 @@ leafletprovidersESP_v <- "v1.3.3"
 #'   )
 #'
 #' leafmap
-addProviderEspTiles <- function(map, provider, layerId = NULL, group = NULL,
-                                options = providerEspTileOptions()) {
+addProviderEspTiles <- function(
+  map,
+  provider,
+  layerId = NULL,
+  group = NULL,
+  options = leaflet::providerTileOptions()
+) {
+  map <- validate_non_empty_arg(map)
+  provider <- validate_non_empty_arg(provider)
+
   # A. Check providers
   prov_list <- mapSpain::esp_tiles_providers
 
   allprovs <- names(prov_list)
 
-
-  if (!provider %in% allprovs) {
-    stop(
-      "No match for provider = '", provider,
-      "' found.\n\nCheck available providers in mapSpain::esp_tiles_providers."
-    )
-  }
+  provider <- match_arg_pretty(provider, allprovs)
 
   # Check type of provider
+  prov_pieces <- validate_provider(provider)
+  iswmts <- guess_provider_type(prov_pieces) == "WMTS"
   thisprov <- prov_list[[provider]]
 
   # Get url
-  # Special case for IDErioja
-  if (grepl("rioja", provider, ignore.case = TRUE)) {
-    iswmts <- TRUE
-  } else {
-    type_prov <- tolower(thisprov$static$service)
-    iswmts <- type_prov == "wmts"
-  }
 
   # Prepare each provider
   if (iswmts) {
@@ -114,9 +106,13 @@ addProviderEspTiles <- function(map, provider, layerId = NULL, group = NULL,
     optionend <- modifyList(tileops, optionend)
     optionend <- do.call(leaflet::tileOptions, optionend)
 
-    leaflet::addTiles(map,
-      urlTemplate = templurl, attribution = attribution,
-      layerId = layerId, group = group, options = optionend
+    leaflet::addTiles(
+      map,
+      urlTemplate = templurl,
+      attribution = attribution,
+      layerId = layerId,
+      group = group,
+      options = optionend
     )
   } else {
     # Build template
@@ -135,12 +131,19 @@ addProviderEspTiles <- function(map, provider, layerId = NULL, group = NULL,
     templurl <- gsub("\\?$", "", temp_pieces$q)
     layers <- temp_pieces$layers
 
-    # Remove parameters only affecting static urls
-    todel <- names(temp_pieces) %in% c(
-      "attribution", "q", "service", "request",
-      "layers", "srs", "width", "height",
-      "bbox"
-    )
+    # Remove arguments only affecting static urls
+    todel <- names(temp_pieces) %in%
+      c(
+        "attribution",
+        "q",
+        "service",
+        "request",
+        "layers",
+        "srs",
+        "width",
+        "height",
+        "bbox"
+      )
 
     names(def_opts) <- tolower(names(def_opts))
 
@@ -156,25 +159,14 @@ addProviderEspTiles <- function(map, provider, layerId = NULL, group = NULL,
 
     optionend <- modifyList(wmsopts, optionend)
 
-    leaflet::addWMSTiles(map,
-      baseUrl = templurl, layers = layers,
-      attribution = attribution, layerId = layerId,
-      group = group, options = optionend
+    leaflet::addWMSTiles(
+      map,
+      baseUrl = templurl,
+      layers = layers,
+      attribution = attribution,
+      layerId = layerId,
+      group = group,
+      options = optionend
     )
   }
 }
-
-#' @rdname addProviderEspTiles
-#' @name providerEspTileOptions
-#'
-#' @details
-#' [providerEspTileOptions()] is a wrapper of [leaflet::providerTileOptions()].
-#'
-#' @param ... Arguments passed on to [leaflet::providerTileOptions()].
-#' @seealso [leaflet::providerTileOptions()], [leaflet::tileOptions()]
-#'
-#' @export
-providerEspTileOptions <- function(...) {
-  ops <- leaflet::providerTileOptions(...)
-  return(ops)
-}
